% Class for creating a CV_camera object as a subclass of the imaging_sensor_model superclass
% CV_CAMERA object describing imaging geometry, based on camera model used 
%       by the Matlab camera calibration toolbox:
%       http://www.vision.caltech.edu/bouguetj/calib_doc/
%
% CV_CAMERA Properties:
%       fc         -  Principal distance, in pixels [1x2]
%       cc         -  Principal point coordinates, in pixels [1x2]
%       kc         -  Distortion coefficients [1x5]
%       alpha_c    -  Tangential distortion parameters [1x2]
%       descriptor -  Description of the sensor [string]
%
%       pd         -  Provided for compatibility. Reading pd returns the
%                       average of fc. Setting pd changes the values of fc
%                       so that the average is pd and the ratio fc(1)/fc(2)
%                       is preserved.
%
% CV_CAMERA Constructors:
%       CV_CAMERA(fc, cc, kc, alpha_c) -  Provide parameter values
%       CV_CAMERA(cam_obj)             -  Provide an existing camera object
%
% CV_CAMERA Methods: 
%       project(vec)       - Projection onto the image plane
%       reproject(points)  - Reprojection from the image plane
%
% NOTE: This camera model is based in pixel units, with the principal point
% giving the coordinates of the optical centre with respect to the top left
% of the image.
%
% Mike James  m.james__AT__lancs.ac.uk