% Class for images with associated sensor models (including position etc).
% R3_IMAGE objects represent an imaging sensor with an associated position
%       and orientation, allowing projection and reprojection to/from an
%       image plane in an external R3 coordinate system.
%
% R3_IMAGE Properties:
%       image               -  Image data (or empty)
%                                image data for an image with c columns, 
%                                  r rows and b bands: matrix with dimensions [r c b]
%                                NOTE: See constructor for initialising
%                                object without an image. Image can be
%                                reset at any later time to either another
%                                image with the same x, y dimensions or an
%                                empty array (to save memory). npX/Y remain
%                                unchanged.
%       sensor_model        -  The sensor model (imaging_sensor_model object or subclass)
%       sensor_position     -  Sensor position in xyz coordinates [1x3] 
%       sensor_pointing     -  Direction of the optic axis (or equivalent) [1x3]
%       acquisition_datetime - Acquisition datetime (not yet implemented)
%       descriptor          -  Description of the sensor [string]
%       image_filepath      -  Path to the image file if available
%       npX                 -  Number of pixels in the X direction (Read only)
%       npY                 -  Number of pixels in the Y direction (Read only) 
%
% R3_IMAGE Constructors:
%       R3_IMAGE(img, sensor_mod, sensor_pos, sensor_point, image_filepath, descriptor) -  Provide parameter values
%                   NOTE: img can be provided as image size only, i.e. as a
%                   vector with values of [npX npY]. This allows properties
%                   npX and npY to be set, without the memory overhead of
%                   storing full image data.
%
% R3_IMAGE Methods: 
%       project_to_image(vec)            - Projection onto the image plane
%       reproject_from_image(im_points)  - Reprojection from the image plane
%
%
% Mike James  m.james__AT__lancs.ac.uk

