% SFM_GEOREF Georeference SfM point clouds
%
% Syntax:
%      SFM_GEOREF()
%      SFM_GEOREF(sfm_folder_path)
%      SFM_GEOREF(bundler_R3_ims)
%      SFM_GEOREF(bundler_R3_ims, ctrl_points)
%      SFM_GEOREF(bundler_R3_ims, ctrl_points, obs)
%      [transform, obs, ctrl_points, R3_ims] = SFM_GEOREF(...)
%
% Sfm_georef is a gui-based Matlab tool for scaling and orienting SfM point
% clouds to real-world coordinates, using observations made directly in the 
% SfM image set. A valid SfM project (in the Bundler format) is required. 
% Folder structures as produced by SFMToolbox:
% (http://www.visual-experiments.com/demos/sfmtoolkit/)
% and Bundler Photogrammetry Package
% (http://blog.neonascent.net/archives/bundler-photogrammetry-package/) are
% directly supported. For scaling a project, at least one distance (a
% control length) between positions that can be directly observed in two or
% more images is needed. For scaling and orienting a project, the real 3d 
% positions of three or more points (control points) that can be observed in
% two or more images, is necessary. Once the transform is determined, this
% can be applied to dense point cloud (.ply) files generated by PMVS2, with
% provision given for merging multiple files into one.
%      SFM_GEOREF()     Provides a dialog box to select an SfM project 
%                       folder to open.
%
%      SFM_GEOREF(sfm_folder_path)
%               sfm_folder_path = path to an SfM project folder
%
%      SFM_GEOREF(bundler_R3_ims)
%               bundler_R3_ims = cell array of R3_image objects representing
%                                the SfM project
% 
%      SFM_GEOREF(bundler_R3_ims, ctrl_points)
%               ctrl_points = R3 points for registering the SfM project
%                   [n 3], for n 3d points.
% 
%      SFM_GEOREF(bundler_R3_ims, ctrl_points, obs)
%               obs = Image observations from the SfM project
%
%      [transform, obs, ctrl_points] = SFM_GEOREF(...)
%               transform = calculated transform structure that relates the
%                           SfM coordinate system to the control coordinate
%                           system. See Matlab's PROCRUSTES for details and
%                           appropriate transform equations.
%               obs       = A structure containing the image observation
%                           data. Can be provided back to sfm_georef as an
%                           input argument.
%               ctrl_points = A structure containing the control data. Can
%                           be supplied back to sfm_georef as an input
%                           argument. 
%
% Mike James  m.james__AT__lancs.ac.uk
% v1.0 30/11/11
